/* Copyright (c) 2009 Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is property of Nordic Semiconductor ASA.
 * Terms and conditions of usage are described in detail in NORDIC
 * SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT.
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRANTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *
 */

/** @file
 * @defgroup uart_example_main main.c
 * @{
 * @ingroup uart_example
 * @brief UART Example Application main file.
 *
 * This file contains the source code for a sample application using UART.
 *
 * @image html example_board_setup_a.jpg "Use board setup A for this example."
 */
 
#include "simple_uart.h"
#include <stdbool.h>
#include <stdint.h>
#include <string.h>
#include "nrf.h"
#include "nrf_gpio.h"
#include "boards.h"
#include "app_uart.h"
#include "app_error.h"

#define UART_BUFFER_SIZE 16

void putstring(char * s)
{
    uint32_t err_code;
    
    uint8_t len = strlen((char *) s);
    for (uint8_t i = 0; i < len; i++)
    {
        err_code = app_uart_put(s[i]);
        APP_ERROR_CHECK(err_code);
    }
}

void app_error_handler(uint32_t err_code, uint32_t line_num, const uint8_t * file_name)
{
    while(1)
    {
    }
}

/** @brief Function for sending 'Start:' string to UART. 
 *  @details Execution is blocked until UART peripheral detects all characters have been sent.
 */
static __INLINE void uart_start()
{
    putstring(" \n\rStart: ");
}

static void uart_evt_handler(app_uart_evt_t * p_evt)
{
    uint8_t value;
    uint32_t err_code;
    switch (p_evt->evt_type)
    {
        case APP_UART_DATA_READY:
            err_code = app_uart_get(&value);
            APP_ERROR_CHECK(err_code);
            err_code = app_uart_put(value);
            APP_ERROR_CHECK(err_code);
            break;
          
        default:
            break;
    }
}

/**
 * @brief Function for main application entry.
 */
int main(void)
{
    app_uart_comm_params_t params;
    memset(&params, 0, sizeof(params));
    
    params.baud_rate = UART_BAUDRATE_BAUDRATE_Baud38400;
    params.tx_pin_no = TX_PIN_NUMBER;
    params.rx_pin_no = RX_PIN_NUMBER;
    params.use_parity = false;
    params.flow_control = APP_UART_FLOW_CONTROL_DISABLED;
    
    static uint8_t rx_buf[UART_BUFFER_SIZE];
    static uint8_t tx_buf[UART_BUFFER_SIZE];
    app_uart_buffers_t bufs;
    bufs.rx_buf = rx_buf;
    bufs.rx_buf_size = UART_BUFFER_SIZE;
    bufs.tx_buf = tx_buf;
    bufs.tx_buf_size = UART_BUFFER_SIZE;
    
    uint32_t err_code;
    err_code = app_uart_init(&params, &bufs, uart_evt_handler, APP_IRQ_PRIORITY_LOW, NULL);
    APP_ERROR_CHECK(err_code);
    
    uart_start();
    while(true)
    {
        
    }
}
/** @} */
